package com.ruoyi.system.service;

import com.ruoyi.system.domain.dto.SysSecretProjectDTO;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author ruoyi
 * @date 2023-11-21
 */
public interface ISysSecretProjectService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SysSecretProjectDTO selectSysSecretProjectById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param sysSecretProjectDTO 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SysSecretProjectDTO> selectSysSecretProjectList(SysSecretProjectDTO sysSecretProjectDTO);

    /**
     * 新增【请填写功能名称】
     * 
     * @param sysSecretProjectDTO 【请填写功能名称】
     * @return 结果
     */
    public int insertSysSecretProject(SysSecretProjectDTO sysSecretProjectDTO);

    /**
     * 修改【请填写功能名称】
     * 
     * @param sysSecretProjectDTO 【请填写功能名称】
     * @return 结果
     */
    public int updateSysSecretProject(SysSecretProjectDTO sysSecretProjectDTO);

    public String  selectSysSecretProjectAddress(SysSecretProjectDTO sysSecretProjectDTO);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteSysSecretProjectByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSysSecretProjectById(Long id);

    int updateIsSwitch(SysSecretProjectDTO sysSecretProjectDTO);
}
